==> roccat-tools-1.6.0.tar.bz2: roccat-tools-1.6.0/libroccatwidget/roccat_color_palette_button.h <==
#ifndef __ROCCAT_COLOR_PALETTE_BUTTON_H__
#define __ROCCAT_COLOR_PALETTE_BUTTON_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * roccat_color_palette_button keeps selection out of a list of colors
 */

#include "roccat_color_button.h"

G_BEGIN_DECLS

#define ROCCAT_COLOR_PALETTE_BUTTON_TYPE (roccat_color_palette_button_get_type())
#define ROCCAT_COLOR_PALETTE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), ROCCAT_COLOR_PALETTE_BUTTON_TYPE, RoccatColorPaletteButtonClass))
#define IS_ROCCAT_COLOR_PALETTE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), ROCCAT_COLOR_PALETTE_BUTTON_TYPE))
#define ROCCAT_COLOR_PALETTE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_COLOR_PALETTE_BUTTON_TYPE, RoccatColorPaletteButton))
#define IS_ROCCAT_COLOR_PALETTE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_COLOR_PALETTE_BUTTON_TYPE))

typedef struct _RoccatColorPaletteButtonClass RoccatColorPaletteButtonClass;
typedef struct _RoccatColorPaletteButton RoccatColorPaletteButton;
typedef struct _RoccatColorPaletteButtonPrivate RoccatColorPaletteButtonPrivate;

struct _RoccatColorPaletteButtonClass {
	RoccatColorButtonClass parent_class;
	void(*value_changed)(RoccatColorPaletteButton *scale);
};

struct _RoccatColorPaletteButton {
	RoccatColorButton button;
	RoccatColorPaletteButtonPrivate *priv;
};

GType roccat_color_palette_button_get_type(void);
GtkWidget *roccat_color_palette_button_new(GdkColor const *colors, size_t length);

void roccat_color_palette_button_set_colors(RoccatColorPaletteButton *color_palette_button, GdkColor const *colors, size_t length);

gint roccat_color_palette_button_get_index(RoccatColorPaletteButton const *color_palette_button);
void roccat_color_palette_button_set_index(RoccatColorPaletteButton *color_palette_button, gint index);

G_END_DECLS

#endif

==> roccat-tools-3.0.0.tar.bz2: roccat-tools-3.0.0/libroccatwidget/roccat_color_palette_button.h <==
#ifndef __ROCCAT_COLOR_PALETTE_BUTTON_H__
#define __ROCCAT_COLOR_PALETTE_BUTTON_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * roccat_color_palette_button keeps selection out of a list of colors
 */

#include "roccat_color_button.h"

G_BEGIN_DECLS

#define ROCCAT_COLOR_PALETTE_BUTTON_TYPE (roccat_color_palette_button_get_type())
#define ROCCAT_COLOR_PALETTE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), ROCCAT_COLOR_PALETTE_BUTTON_TYPE, RoccatColorPaletteButtonClass))
#define IS_ROCCAT_COLOR_PALETTE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), ROCCAT_COLOR_PALETTE_BUTTON_TYPE))
#define ROCCAT_COLOR_PALETTE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_COLOR_PALETTE_BUTTON_TYPE, RoccatColorPaletteButton))
#define IS_ROCCAT_COLOR_PALETTE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_COLOR_PALETTE_BUTTON_TYPE))

typedef struct _RoccatColorPaletteButtonClass RoccatColorPaletteButtonClass;
typedef struct _RoccatColorPaletteButton RoccatColorPaletteButton;
typedef struct _RoccatColorPaletteButtonPrivate RoccatColorPaletteButtonPrivate;

struct _RoccatColorPaletteButtonClass {
	RoccatColorButtonClass parent_class;
	void(*value_changed)(RoccatColorPaletteButton *scale);
};

struct _RoccatColorPaletteButton {
	RoccatColorButton button;
	RoccatColorPaletteButtonPrivate *priv;
};

GType roccat_color_palette_button_get_type(void);
GtkWidget *roccat_color_palette_button_new(void);

void roccat_color_palette_button_set_colors(RoccatColorPaletteButton *color_palette_button, GdkColor const *colors, size_t length);

gint roccat_color_palette_button_get_index(RoccatColorPaletteButton const *color_palette_button);
void roccat_color_palette_button_set_index(RoccatColorPaletteButton *color_palette_button, gint index);

G_END_DECLS

#endif
